@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainUserlistWidgetContainer.php 4469 2011-11-26 10:08:56Z fishbone $
+ * @version    SVN: $Id: admin_mainUserlistWidgetContainer.php 4993 2012-06-26 12:14:34Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainUserBaseWidgetContainer.php');
@@ -20,7 +20,6 @@ require_once($gEnvManager->getIncludePath() . '/common/userInfo.php');		// ユ
 class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;		// システムDBオブジェクト
 	private $serialNo;	// シリアルNo
 	private $serialArray = array();		// 表示されているコンテンツシリアル番号
 	private $userTypeArray;		// ユーザ種別(-1=未承認ユーザ、0=仮ユーザ、10=一般ユーザ、50=システム運営者、100=システム管理者)
@@ -35,6 +34,8 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 	const CALENDAR_ICON_FILE = '/images/system/calendar.png';		// カレンダーアイコン
 	const ACTIVE_ICON_FILE = '/images/system/active.png';			// 公開中アイコン
 	const INACTIVE_ICON_FILE = '/images/system/inactive.png';		// 非公開アイコン
+	const SKYPE_STATUS_ICON_HEIGHT = 22;	// Skype状態アイコン
+	const SKYPE_STATUS_ICON_WIDTH = 91; 	// Skype状態アイコン
 	
 	/**
 	 * コンストラクタ
@@ -46,7 +47,6 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 		
 		// DB接続オブジェクト作成
 		$this->db = new admin_mainDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
 		
 		// ユーザタイプメニュー項目
 		$this->userTypeArray = array(	array(	'name' => '-- ' . $this->_('Unselected') . ' --',		'value' => ''),		// 未選択
@@ -128,6 +128,10 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 			$localeText['label_start_date'] = $this->_('Start Date:');		// 開始日
 			$localeText['label_end_date'] = $this->_('End Date:');		// 終了日
 			$localeText['label_hour'] = $this->_('Hour:');		// 時間
+			$localeText['label_email'] = $this->_('Email');		// Eメール
+			$localeText['label_skype_account'] = $this->_('Skype Account');		// Skypeアカウント
+			$localeText['label_update_user'] = $this->_('Update User');		// 更新者
+			$localeText['label_update_dt'] = $this->_('Update Date Time');		// 更新日時
 			$localeText['label_calendar'] = $this->_('Calendar');		// カレンダー
 			$localeText['label_go_back'] = $this->_('Go back');		// 戻る
 			$localeText['label_delete'] = $this->_('Delete');	// 削除
@@ -149,6 +153,8 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 			$localeText['label_admin'] = $this->_('Administration');		// 管理権限
 			$localeText['label_login_count'] = $this->_('Count');		// 回数
 			$localeText['label_update_dt'] = $this->_('Update Date');		// 更新日
+			$localeText['label_email'] = $this->_('Email');		// Eメール
+			$localeText['label_others'] = $this->_('Others');		// その他
 			$localeText['label_new'] = $this->_('New');					// 新規
 			$localeText['label_edit'] = $this->_('Edit');				// 編集
 			$localeText['label_delete'] = $this->_('Delete');			// 削除
@@ -265,6 +271,8 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 			if (empty($end_time)) $end_time = '00:00';		// 日付が入っているときは時間にデフォルト値を設定
 		}
 		if (!empty($end_time)) $end_time = $this->convertToProperTime($end_time, 1/*時分フォーマット*/);
+		$email = $request->trimValueOf('item_email');		// Eメール
+		$skypeAccount = $request->trimValueOf('item_skype_account');		// Skypeアカウント
 		
 		// ユーザグループを取得
 		$this->userGroupArray = array();
@@ -283,7 +291,8 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 			// 入力チェック
 			$this->checkInput($name, $this->_('Name'));		// 名前
 			$this->checkInput($account, $this->_('Login Account'));	// アカウント
-			
+			$this->checkMailAddress($email, $this->_('Email'), true);		// Eメール
+		
 			// 期間範囲のチェック
 			if (!empty($start_date) && !empty($end_date)){
 				if (strtotime($start_date . ' ' . $start_time) >= strtotime($end_date . ' ' . $end_time)) $this->setUserErrorMsg($this->_('Invalid active term.'));	// 有効期間が不正です
@@ -293,7 +302,7 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 			// 設定データを取得
 			$ret = $this->db->getUserBySerial($this->serialNo, $row, $groupRows);
 			if ($ret){
-				if ($row['lu_account'] != $account && $this->sysDb->isExistsAccount($account)) $this->setMsg(self::MSG_USER_ERR, $this->_('Login account is duplicated.'));		// アカウントが重複しています
+				if ($row['lu_account'] != $account && $this->_db->isExistsAccount($account)) $this->setMsg(self::MSG_USER_ERR, $this->_('Login account is duplicated.'));		// アカウントが重複しています
 			} else {
 				$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in getting data.'));			// データ取得に失敗しました
 			}
@@ -325,19 +334,25 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 					$endDt = $this->gEnv->getInitValueOfTimestamp();
 				}
 				
-				$ret = $this->_db->updateLoginUser($this->serialNo, $name, $account, $password, $this->userType, $canLogin, $startDt, $endDt, $newSerial, $this->userGroupArray);
+				// 追加項目
+				$otherParams = array();
+				$otherParams['lu_email'] = $email;		// Eメール
+				$otherParams['lu_skype_account'] = $skypeAccount;		// Skypeアカウント
+				$ret = $this->_db->updateLoginUser($this->serialNo, $name, $account, $password, $this->userType, $canLogin, $startDt, $endDt, $newSerial,
+													null, null, $this->userGroupArray, $otherParams);
 				if ($ret){		// データ追加成功のとき
 					$this->setMsg(self::MSG_GUIDANCE, $this->_('Item updated.'));		// データを更新しました
 					$this->serialNo = $newSerial;
 					$reloadData = true;		// データの再読み込み
 				} else {
-					$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in deleting item.'));		// データ更新に失敗しました
+					$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in updating item.'));		// データ更新に失敗しました
 				}
 			}
 		} else if ($act == 'add'){		// 新規追加のとき
 			// 入力チェック
 			$this->checkInput($name, $this->_('Name'));		// 名前
 			$this->checkInput($account, $this->_('Login Account'));	// アカウント
+			$this->checkMailAddress($email, $this->_('Email'), true);		// Eメール
 			if ($this->userType == '') $this->setUserErrorMsg($this->_('User type not selected.'));		// ユーザ種別が選択されていません
 			
 			// 期間範囲のチェック
@@ -346,7 +361,7 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 			}
 			
 			// アカウント重複チェック
-			if ($this->sysDb->isExistsAccount($account)) $this->setMsg(self::MSG_USER_ERR, $this->_('Login account is duplicated.'));	// アカウントが重複しています
+			if ($this->_db->isExistsAccount($account)) $this->setMsg(self::MSG_USER_ERR, $this->_('Login account is duplicated.'));	// アカウントが重複しています
 						
 			// エラーなしの場合は、データを登録
 			if ($this->getMsgCount() == 0){
@@ -372,7 +387,12 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 					$endDt = $this->gEnv->getInitValueOfTimestamp();
 				}
 				
-				$ret = $this->_db->addNewLoginUser($name, $account, $password, $this->userType, $canLogin, $startDt, $endDt, $newSerial);
+				// 追加項目
+				$otherParams = array();
+				$otherParams['lu_email'] = $email;		// Eメール
+				$otherParams['lu_skype_account'] = $skypeAccount;		// Skypeアカウント
+				
+				$ret = $this->_db->addNewLoginUser($name, $account, $password, $this->userType, $canLogin, $startDt, $endDt, $newSerial, '', '', $this->userGroupArray, $otherParams);
 				if ($ret){		// データ追加成功のとき
 					$this->setMsg(self::MSG_GUIDANCE, $this->_('Item added.'));	// データを追加しました
 					$this->serialNo = $newSerial;
@@ -411,12 +431,19 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 				$start_time = $this->convertToDispTime($row['lu_active_start_dt'], 1/*時分*/);	// 有効期間開始時間
 				$end_date = $this->convertToDispDate($row['lu_active_end_dt']);	// 有効期間終了日
 				$end_time = $this->convertToDispTime($row['lu_active_end_dt'], 1/*時分*/);	// 有効期間終了時間
-				
+				$email = $row['lu_email'];		// Eメール
+				$skypeAccount = $row['lu_skype_account'];		// Skypeアカウント
+		
 				// ユーザグループ取得
 				$this->userGroupArray = $this->getUserGroup($groupRows);
 				
 				// 一般ユーザの場合のみグループ選択可能
 				if ($row['lu_user_type'] == UserInfo::USER_TYPE_NORMAL) $this->canSelectGroup = true;
+				
+				// データ登録情報取得
+				$ret = $this->_db->getLoginUserRecordById($row['lu_create_user_id'], $userInfo);
+				if ($ret) $updateUser = $userInfo['lu_name'];	// データ登録者
+				$updateDt = $row['lu_create_dt'];			// データ登録日時
 			}
 		}
 		// ユーザタイプ選択メニュー作成
@@ -439,7 +466,11 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 		$this->tmpl->addVar("_widget", "start_time", $start_time);	// 有効期間開始時間
 		$this->tmpl->addVar("_widget", "end_date", $end_date);	// 有効期間終了日
 		$this->tmpl->addVar("_widget", "end_time", $end_time);	// 有効期間終了時間
-		
+		$this->tmpl->addVar("_widget", "email", $this->convertToDispString($email));		// Eメール
+		$this->tmpl->addVar("_widget", "skype_account", $this->convertToDispString($skypeAccount));		// Skypeアカウント
+		$this->tmpl->addVar("_widget", "update_user", $this->convertToDispString($updateUser));	// データ登録者
+		$this->tmpl->addVar("_widget", "update_dt", $this->convertToDispDateTime($updateDt));	// データ登録日時
+
 		if (empty($this->serialNo)){		// ユーザIDが空のときは新規とする
 			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 新規登録ボタン表示
 		} else {
@@ -507,19 +538,29 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 		// ログイン状況画面URL
 		$loginStatusUrl = '?task=loginstatus_history&account=' . $fetchedRow['lu_account'];
 		
+		// Skype状態表示用タグ作成
+		$skypeStatusTag = '';
+		$skypeAccount = $fetchedRow['lu_skype_account'];
+		if (!empty($skypeAccount)){
+			$skypeStatusTag = '<a href="skype:' . $skypeAccount . '?call"><img src="http://mystatus.skype.com/bigclassic/' 
+								. $skypeAccount . '" style="border: none;" width="' . self::SKYPE_STATUS_ICON_WIDTH . '" height="' . self::SKYPE_STATUS_ICON_HEIGHT . '" alt="ログイン状態" /></a>';
+		}
+		
 		$row = array(
 			'index' => $index,													// 行番号
 			'serial' => $this->convertToDispString($fetchedRow['lu_serial']),			// シリアル番号
 			'id' => $this->convertToDispString($fetchedRow['lu_id']),			// ID
 			'name' => $this->convertToDispString($fetchedRow['lu_name']),		// 名前
 			'account' => $this->convertToDispString($fetchedRow['lu_account']),		// アカウント
+			'email' => $this->convertToDispString($fetchedRow['lu_email']),		// Eメール
 			'user_type' => $userType,		// ユーザ種別
-			'update_dt' => $this->convertToDispDateTime($fetchedRow['lu_create_dt']),	// 更新日時
+			'update_dt' => $this->convertToDispDateTime($fetchedRow['lu_create_dt'], 0, 10/*時分表示*/),	// 更新日時
 			'is_admin' => $isAdmin,													// 管理者権限があるかどうか
 			'can_login' => $canLogin,												// ログイン可能かどうか
 			'login_count' => $loginCount,			// ログイン回数
 			'login_status_url' => $this->convertUrlToHtmlEntity($loginStatusUrl),	// ログイン状況画面URL
-			'selected' => $selected												// 項目選択用ラジオボタン
+			'selected' => $selected,												// 項目選択用ラジオボタン
+			'others' => $skypeStatusTag												// その他
 		);
 		$this->tmpl->addVars('userlist', $row);
 		$this->tmpl->parseTemplate('userlist', 'a');
