@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2009-2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: contactus_freelayout2WidgetContainer.php 3078 2010-04-28 08:22:48Z fishbone $
+ * @version    SVN: $Id: contactus_freelayout2WidgetContainer.php 3248 2010-06-16 07:09:38Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -87,6 +87,7 @@ class contactus_freelayout2WidgetContainer extends BaseWidgetContainer
 		$emailReceiver = $targetObj->emailReceiver;		// メール受信者
 		$emailSubject = $targetObj->emailSubject;		// メール件名
 		$sendUserEmail = $targetObj->sendUserEmail;	// 入力ユーザ向けメールを送信するかどうか
+		$userEmailReply = $targetObj->userEmailReply;					// 入力ユーザ向けメール返信先メールアドレス
 		$userEmailSubject = $targetObj->userEmailSubject;				// 入力ユーザ向けメールタイトル
 		$userEmailFormat = $targetObj->userEmailFormat;				// 入力ユーザ向けメール本文フォーマット
 		$baseTemplate = $targetObj->baseTemplate;		// 入力エリア作成用ベーステンプレート
@@ -234,8 +235,9 @@ class contactus_freelayout2WidgetContainer extends BaseWidgetContainer
 							if ($ret && !empty($sendUserEmail)){
 								// 送信先を取得
 								if (!empty($userEmail)){
+									// 返信先メールアドレスが設定されている場合は設定メールアドレスを使用
 									$ret = $this->gInstance->getMailManager()->sendFormMail(2/*手動送信*/, $this->gEnv->getCurrentWidgetId(), 
-																$userEmail, $fromAddress, $email, $userEmailSubject, ''/*フォーム内容を指定*/, $mailParam, ''/*cc*/, ''/*bcc*/, $userEmailFormat);
+																$userEmail, $fromAddress, $userEmailReply, $userEmailSubject, ''/*フォーム内容を指定*/, $mailParam, ''/*cc*/, ''/*bcc*/, $userEmailFormat);
 								}
 							}
 						}
