@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_contentWidgetContainer.php 5027 2012-07-09 06:24:07Z fishbone $
+ * @version    SVN: $Id: default_contentWidgetContainer.php 5052 2012-07-23 02:41:11Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('default_content') . '/default_contentBaseWidgetContainer.php');
@@ -218,8 +218,7 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 				}
 				if ($downloadCompleted){		// ダウンロード処理完了のとき
 					// ダウンロードログを残す
-	//				if (!$this->isSystemManageUser){		// システム運用者以上の場合はカウントしない
-	//				}
+					$this->gInstance->getAnalyzeManager()->logContentDownload(default_contentCommonDef::$_viewContentType . default_contentCommonDef::DOWNLOAD_CONTENT_TYPE, $fileId);
 				} else {
 					$msgDetail = '';
 					if (!empty($contentId)) $msgDetail .= 'コンテンツID=' . $contentId;
@@ -480,15 +479,35 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 		$this->headDesc .= $fetchedRow['cn_meta_description'];
 		$this->headKeyword .= $fetchedRow['cn_meta_keywords'];
 		
-		// 表示コンテンツ作成
+		$headClassStr = $this->gDesign->getDefaultContentHeadClassString();			// コンテンツヘッダ用CSSクラス
+
+		// コンテンツ編集権限がある場合はボタンを表示
+		$buttonList = '';
+		if (!empty($this->showEdit) && $this->isSystemManageUser){
+			$iconUrl = $this->gEnv->getRootUrl() . self::EDIT_ICON_FILE;		// 編集アイコン
+			$iconTitle = '編集';
+			$editImg = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . 
+						'" alt="' . $iconTitle . '" title="' . $iconTitle . '" style="border:none;" />';
+			$buttonList = '<a href="javascript:void(0);" onclick="editContent(' . $contentId . ');">' . $editImg . '</a>';
+			switch (default_contentCommonDef::$_deviceType){		// デバイスごとの処理
+				case 0:		// PC
+				default:
+					$buttonList = '<div style="text-align:right;position:absolute;top:' . $this->editIconPos . 'px;z-index:10;width:100%;">' . $buttonList . '</div>';
+					break;
+				case 1:		// 携帯
+				case 2:		// スマートフォン
+					$buttonList = '<div style="text-align:right;position:absolute;top:' . $this->editIconPos . 'px;right:5px;z-index:10;width:100%;">' . $buttonList . '</div>';
+					break;
+			}
+			$this->editIconPos += self::EDIT_ICON_NEXT_POS;			// 編集アイコンの位置を更新
+		}
+		
+		// ##### 表示コンテンツ作成 #####
 		if ($this->inputPassword){			// パスワード入力のとき
 			$contentText = self::$_configArray[default_contentCommonDef::$CF_PASSWORD_CONTENT];		// パスワード画面コンテンツ
+			$attachFileTag = '';		// 添付ファイルダウンロード用リンク
 		} else {
-			// Magic3マクロ変換
-			$contentInfo = array();
-			$contentInfo[M3_TAG_MACRO_CONTENT_TITLE] = $fetchedRow['cn_name'];			// コンテンツ置換キー(タイトル)
-			$contentInfo[M3_TAG_MACRO_CONTENT_UPDATE_DT] = $fetchedRow['cn_create_dt'];		// コンテンツ置換キー(更新日時)
-			$contentText = $this->convertM3ToHtml($fetchedRow['cn_html'], true/*改行コーをbrタグに変換*/, $contentInfo);
+			$contentText = $fetchedRow['cn_html'];
 			
 			// 添付ファイルダウンロード用リンク
 			$attachFileTag = '';
@@ -513,27 +532,16 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 			}
 		}
 		
-		$headClassStr = $this->gDesign->getDefaultContentHeadClassString();			// コンテンツヘッダ用CSSクラス
-
-		// コンテンツ編集権限がある場合はボタンを表示
-		$buttonList = '';
-		if (!empty($this->showEdit) && $this->isSystemManageUser){
-			$iconUrl = $this->gEnv->getRootUrl() . self::EDIT_ICON_FILE;		// 編集アイコン
-			$iconTitle = '編集';
-			$editImg = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . 
-						'" alt="' . $iconTitle . '" title="' . $iconTitle . '" style="border:none;" />';
-			$buttonList = '<a href="javascript:void(0);" onclick="editContent(' . $contentId . ');">' . $editImg . '</a>';
-			switch (default_contentCommonDef::$_deviceType){		// デバイスごとの処理
-				case 0:		// PC
-				default:
-					$buttonList = '<div style="text-align:right;position:absolute;top:' . $this->editIconPos . 'px;z-index:10;width:100%;">' . $buttonList . '</div>';
-					break;
-				case 1:		// 携帯
-				case 2:		// スマートフォン
-					$buttonList = '<div style="text-align:right;position:absolute;top:' . $this->editIconPos . 'px;right:5px;z-index:10;width:100%;">' . $buttonList . '</div>';
-					break;
-			}
-			$this->editIconPos += self::EDIT_ICON_NEXT_POS;			// 編集アイコンの位置を更新
+		$contentParam = array('BODY' => $contentText, 'FILES' => $attachFileTag, 'PAGES' => '', 'LINKS' => '');
+		$contentText = $this->createDetailContent($contentParam);
+		
+		if (!$this->inputPassword){			// パスワード入力でないとき
+			// Magic3マクロ変換
+			$contentInfo = array();
+			$contentInfo[M3_TAG_MACRO_CONTENT_ID] = $fetchedRow['cn_id'];			// コンテンツ置換キー(コンテンツID)
+			$contentInfo[M3_TAG_MACRO_CONTENT_TITLE] = $fetchedRow['cn_name'];			// コンテンツ置換キー(タイトル)
+			$contentInfo[M3_TAG_MACRO_CONTENT_UPDATE_DT] = $fetchedRow['cn_create_dt'];		// コンテンツ置換キー(更新日時)
+			$contentText = $this->convertM3ToHtml($contentText, true/*改行コードをbrタグに変換*/, $contentInfo);
 		}
 		
 		$row = array(
@@ -543,8 +551,7 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 			'content_id' => $contentId,
 			'func_name'	=> $funcName,	// パスワードチェック用関数
 			'form_name'	=> $formName,	// パスワードチェック用フォーム名
-			'button_list' => $buttonList,	// 記事編集ボタン
-			'download' => $attachFileTag	// 添付ファイル
+			'button_list' => $buttonList	// 記事編集ボタン
 		);
 		$this->tmpl->addVars('contentlist', $row);
 		$this->tmpl->parseTemplate('contentlist', 'a');
@@ -641,5 +648,25 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 		}
 		return $isActive;
 	}
+	/**
+	 * 詳細コンテンツを作成
+	 *
+	 * @param array	$contentParam		コンテンツ作成用パラメータ
+	 * @return string			作成コンテンツ
+	 */
+	function createDetailContent($contentParam)
+	{
+		$contentText = self::$_configArray[default_contentCommonDef::$CF_LAYOUT_VIEW_DETAIL];			// コンテンツレイアウト(詳細表示)
+		
+		// コンテンツを作成
+		$keys = array_keys($contentParam);
+		for ($i = 0; $i < count($keys); $i++){
+			$key = $keys[$i];
+			$value = $contentParam[$key];
+			
+			$contentText = str_replace(M3_TAG_START . $key . M3_TAG_END, $value, $contentText);
+		}
+		return $contentText;
+	}
 }
 ?>
